Module discord_flows::model::application_command
source · Structs
- An interaction when a user invokes a slash command.
- The command data payload.
- A set of a parameter and a value from the user.
- The resolved data of a command data interaction payload. It contains the objects of
CommandDataOptions.
Enums
- The resolved value of an
CommandDataOption. - The resolved value of a
CommandData::target_id.