pub enum DefaultAvatar {
    Blurple,
    Grey,
    Green,
    Orange,
    Red,
}
An enum that represents a default avatar.

The default avatar is calculated via the result of discriminator % 5.

The has of the avatar can be retrieved via calling Self::name on the enum.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Blurple

The avatar when the result is 0.



Grey

The avatar when the result is 1.



Green

The avatar when the result is 2.



Orange

The avatar when the result is 3.



Red

The avatar when the result is 4.

Implementations

source

impl DefaultAvatar

source

pub fn name(self) -> Result<String, Error>

Retrieves the String hash of the default avatar.

Errors

May return a Error::Json if there is a serialization error.