Enum discord_flows::model::guild::GuildContainer
source · pub enum GuildContainer {
Guild(PartialGuild),
Id(GuildId),
}Expand description
A container for guilds.
This is used to differentiate whether a guild itself can be used or whether a guild needs to be retrieved from the cache.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Guild(PartialGuild)
A guild which can have its contents directly searched.
Id(GuildId)
A guild’s id, which can be used to search the cache for a guild.