Struct discord_flows::model::guild::GuildPreview
source · pub struct GuildPreview {
pub id: GuildId,
pub name: String,
pub icon: Option<String>,
pub splash: Option<String>,
pub discovery_splash: Option<String>,
pub emojis: Vec<Emoji, Global>,
pub features: Vec<String, Global>,
pub approximate_member_count: u64,
pub approximate_presence_count: u64,
pub description: Option<String>,
}Expand description
Preview Guild information.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.id: GuildIdThe guild Id.
name: StringThe guild name.
icon: Option<String>The guild icon hash if it has one.
splash: Option<String>The guild splash hash if it has one.
discovery_splash: Option<String>The guild discovery splash hash it it has one.
emojis: Vec<Emoji, Global>The custom guild emojis.
features: Vec<String, Global>The guild features. See Guild::features
approximate_member_count: u64Approximate number of members in this guild.
approximate_presence_count: u64Approximate number of online members in this guild.
description: Option<String>The description for the guild, if the guild has the DISCOVERABLE feature.