Struct discord_flows::model::guild::GuildPrune
source · pub struct GuildPrune {
pub pruned: u64,
}Expand description
Representation of the number of members that would be pruned by a guild prune operation.
Fields
pruned: u64The number of members that would be pruned by the operation.