Struct discord_flows::model::guild::Member
source · pub struct Member {
pub deaf: bool,
pub guild_id: GuildId,
pub joined_at: Option<Timestamp>,
pub mute: bool,
pub nick: Option<String>,
pub roles: Vec<RoleId, Global>,
pub user: User,
pub pending: bool,
pub premium_since: Option<Timestamp>,
pub permissions: Option<Permissions>,
pub avatar: Option<String>,
pub communication_disabled_until: Option<Timestamp>,
}Expand description
Information about a member of a guild.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.deaf: boolIndicator of whether the member can hear in voice channels.
guild_id: GuildIdThe unique Id of the guild that the member is a part of.
joined_at: Option<Timestamp>Timestamp representing the date when the member joined.
mute: boolIndicator of whether the member can speak in voice channels.
nick: Option<String>The member’s nickname, if present.
Can’t be longer than 32 characters.
roles: Vec<RoleId, Global>Vector of Ids of Roles given to the member.
user: UserAttached User struct.
pending: boolIndicator that the member hasn’t accepted the rules of the guild yet.
Timestamp representing the date since the member is boosting the guild.
permissions: Option<Permissions>The total permissions of the member in a channel, including overrides.
This is only Some when returned in an Interaction object.
avatar: Option<String>The guild avatar hash
communication_disabled_until: Option<Timestamp>When the user’s timeout will expire and the user will be able to communicate in the guild again.
Will be None or a time in the past if the user is not timed out.