Struct discord_flows::model::invite::Invite
source · pub struct Invite {
pub approximate_member_count: Option<u64>,
pub approximate_presence_count: Option<u64>,
pub code: String,
pub channel: InviteChannel,
pub guild: Option<InviteGuild>,
pub inviter: Option<User>,
pub target_type: Option<InviteTargetType>,
pub target_user: Option<UserId>,
pub target_application: Option<ApplicationId>,
pub expires_at: Option<Timestamp>,
pub stage_instance: Option<InviteStageInstance>,
}Expand description
Information about an invite code.
Information can not be accessed for guilds the current user is banned from.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.approximate_member_count: Option<u64>approximate_presence_count: Option<u64>The approximate number of Members with an active session in the
related Guild.
An active session is defined as an open, heartbeating WebSocket connection. These include invisible members.
code: StringThe unique code for the invite.
channel: InviteChannelA representation of the minimal amount of information needed about the
GuildChannel being invited to.
guild: Option<InviteGuild>A representation of the minimal amount of information needed about the
Guild being invited to.
inviter: Option<User>A representation of the minimal amount of information needed about the
User that created the invite.
This can be None for invites created by Discord such as invite-widgets
or vanity invite links.
target_type: Option<InviteTargetType>The type of target for this voice channel invite.
target_user: Option<UserId>The user whose stream to display for this voice channel stream invite.
Only shows up if target_type is Stream.
target_application: Option<ApplicationId>The embedded application to open for this voice channel embedded application invite.
Only shows up if target_type is EmmbeddedApplication.
expires_at: Option<Timestamp>The expiration date of this invite, returned from Http::get_invite when
with_expiration is true.
stage_instance: Option<InviteStageInstance>The Stage instance data if there is a public Stage instance in the Stage channel this invite is for.