Struct discord_flows::model::ActivityAssets
source · pub struct ActivityAssets {
pub large_image: Option<String>,
pub large_text: Option<String>,
pub small_image: Option<String>,
pub small_text: Option<String>,
}Expand description
The assets for an activity.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.large_image: Option<String>The ID for a large asset of the activity, usually a snowflake.
large_text: Option<String>Text displayed when hovering over the large image of the activity.
small_image: Option<String>The ID for a small asset of the activity, usually a snowflake.
small_text: Option<String>Text displayed when hovering over the small image of the activity.