Struct discord_flows::model::ActivityFlags
source · pub struct ActivityFlags { /* private fields */ }Expand description
A set of flags defining what is in an activity’s payload.
Implementations
sourceimpl ActivityFlags
impl ActivityFlags
sourcepub const INSTANCE: ActivityFlags = _
pub const INSTANCE: ActivityFlags = _
Whether the activity is an instance activity.
sourcepub const JOIN: ActivityFlags = _
pub const JOIN: ActivityFlags = _
Whether the activity is joinable.
sourcepub const SPECTATE: ActivityFlags = _
pub const SPECTATE: ActivityFlags = _
Whether the activity can be spectated.
sourcepub const JOIN_REQUEST: ActivityFlags = _
pub const JOIN_REQUEST: ActivityFlags = _
Whether a request can be sent to join the user’s party.
sourcepub const SYNC: ActivityFlags = _
pub const SYNC: ActivityFlags = _
Whether the activity can be synced.
sourcepub const PLAY: ActivityFlags = _
pub const PLAY: ActivityFlags = _
Whether the activity can be played.
sourcepub const PARTY_PRIVACY_FRIENDS: ActivityFlags = _
pub const PARTY_PRIVACY_FRIENDS: ActivityFlags = _
Whether the activity party is friend only.
sourcepub const PARTY_PRIVACY_VOICE_CHANNEL: ActivityFlags = _
pub const PARTY_PRIVACY_VOICE_CHANNEL: ActivityFlags = _
Whether the activity party is in a voice channel.
sourcepub const EMBEDDED: ActivityFlags = _
pub const EMBEDDED: ActivityFlags = _
Whether the activity can be embedded.
sourcepub const fn empty() -> ActivityFlags
pub const fn empty() -> ActivityFlags
Returns an empty set of flags.
sourcepub const fn all() -> ActivityFlags
pub const fn all() -> ActivityFlags
Returns the set containing all flags.
sourcepub const fn from_bits(bits: u64) -> Option<ActivityFlags>
pub const fn from_bits(bits: u64) -> Option<ActivityFlags>
Convert from underlying bit representation, unless that representation contains bits that do not correspond to a flag.
sourcepub const fn from_bits_truncate(bits: u64) -> ActivityFlags
pub const fn from_bits_truncate(bits: u64) -> ActivityFlags
Convert from underlying bit representation, dropping any bits that do not correspond to flags.
sourcepub const unsafe fn from_bits_unchecked(bits: u64) -> ActivityFlags
pub const unsafe fn from_bits_unchecked(bits: u64) -> ActivityFlags
Convert from underlying bit representation, preserving all bits (even those not corresponding to a defined flag).
Safety
The caller of the bitflags! macro can chose to allow or
disallow extra bits for their bitflags type.
The caller of from_bits_unchecked() has to ensure that
all bits correspond to a defined flag or that extra bits
are valid for this bitflags type.
sourcepub const fn intersects(&self, other: ActivityFlags) -> bool
pub const fn intersects(&self, other: ActivityFlags) -> bool
Returns true if there are flags common to both self and other.
sourcepub const fn contains(&self, other: ActivityFlags) -> bool
pub const fn contains(&self, other: ActivityFlags) -> bool
Returns true if all of the flags in other are contained within self.
sourcepub fn insert(&mut self, other: ActivityFlags)
pub fn insert(&mut self, other: ActivityFlags)
Inserts the specified flags in-place.
sourcepub fn remove(&mut self, other: ActivityFlags)
pub fn remove(&mut self, other: ActivityFlags)
Removes the specified flags in-place.
sourcepub fn toggle(&mut self, other: ActivityFlags)
pub fn toggle(&mut self, other: ActivityFlags)
Toggles the specified flags in-place.
sourcepub fn set(&mut self, other: ActivityFlags, value: bool)
pub fn set(&mut self, other: ActivityFlags, value: bool)
Inserts or removes the specified flags depending on the passed value.
sourcepub const fn intersection(self, other: ActivityFlags) -> ActivityFlags
pub const fn intersection(self, other: ActivityFlags) -> ActivityFlags
Returns the intersection between the flags in self and
other.
Specifically, the returned set contains only the flags which are
present in both self and other.
This is equivalent to using the & operator (e.g.
ops::BitAnd), as in flags & other.
sourcepub const fn union(self, other: ActivityFlags) -> ActivityFlags
pub const fn union(self, other: ActivityFlags) -> ActivityFlags
Returns the union of between the flags in self and other.
Specifically, the returned set contains all flags which are
present in either self or other, including any which are
present in both (see Self::symmetric_difference if that
is undesirable).
This is equivalent to using the | operator (e.g.
ops::BitOr), as in flags | other.
sourcepub const fn difference(self, other: ActivityFlags) -> ActivityFlags
pub const fn difference(self, other: ActivityFlags) -> ActivityFlags
Returns the difference between the flags in self and other.
Specifically, the returned set contains all flags present in
self, except for the ones present in other.
It is also conceptually equivalent to the “bit-clear” operation:
flags & !other (and this syntax is also supported).
This is equivalent to using the - operator (e.g.
ops::Sub), as in flags - other.
sourcepub const fn symmetric_difference(self, other: ActivityFlags) -> ActivityFlags
pub const fn symmetric_difference(self, other: ActivityFlags) -> ActivityFlags
Returns the symmetric difference between the flags
in self and other.
Specifically, the returned set contains the flags present which
are present in self or other, but that are not present in
both. Equivalently, it contains the flags present in exactly
one of the sets self and other.
This is equivalent to using the ^ operator (e.g.
ops::BitXor), as in flags ^ other.
sourcepub const fn complement(self) -> ActivityFlags
pub const fn complement(self) -> ActivityFlags
Returns the complement of this set of flags.
Specifically, the returned set contains all the flags which are
not set in self, but which are allowed for this type.
Alternatively, it can be thought of as the set difference
between Self::all() and self (e.g. Self::all() - self)
This is equivalent to using the ! operator (e.g.
ops::Not), as in !flags.