pub struct InteractionApplicationCommandCallbackDataFlags { /* private fields */ }Expand description
The flags for an interaction response message.
Implementations
sourceimpl MessageFlags
impl MessageFlags
sourcepub const SUPPRESS_EMBEDS: MessageFlags = _
pub const SUPPRESS_EMBEDS: MessageFlags = _
Do not include any embeds when serializing this message.
sourcepub const EPHEMERAL: MessageFlags = _
pub const EPHEMERAL: MessageFlags = _
Interaction message will only be visible to sender and will be quickly deleted.
sourcepub const fn empty() -> MessageFlags
pub const fn empty() -> MessageFlags
Returns an empty set of flags.
sourcepub const fn all() -> MessageFlags
pub const fn all() -> MessageFlags
Returns the set containing all flags.
sourcepub const fn from_bits(bits: u64) -> Option<MessageFlags>
pub const fn from_bits(bits: u64) -> Option<MessageFlags>
Convert from underlying bit representation, unless that representation contains bits that do not correspond to a flag.
sourcepub const fn from_bits_truncate(bits: u64) -> MessageFlags
pub const fn from_bits_truncate(bits: u64) -> MessageFlags
Convert from underlying bit representation, dropping any bits that do not correspond to flags.
sourcepub const unsafe fn from_bits_unchecked(bits: u64) -> MessageFlags
pub const unsafe fn from_bits_unchecked(bits: u64) -> MessageFlags
Convert from underlying bit representation, preserving all bits (even those not corresponding to a defined flag).
Safety
The caller of the bitflags! macro can chose to allow or
disallow extra bits for their bitflags type.
The caller of from_bits_unchecked() has to ensure that
all bits correspond to a defined flag or that extra bits
are valid for this bitflags type.
sourcepub const fn intersects(&self, other: MessageFlags) -> bool
pub const fn intersects(&self, other: MessageFlags) -> bool
Returns true if there are flags common to both self and other.
sourcepub const fn contains(&self, other: MessageFlags) -> bool
pub const fn contains(&self, other: MessageFlags) -> bool
Returns true if all of the flags in other are contained within self.
sourcepub fn insert(&mut self, other: MessageFlags)
pub fn insert(&mut self, other: MessageFlags)
Inserts the specified flags in-place.
sourcepub fn remove(&mut self, other: MessageFlags)
pub fn remove(&mut self, other: MessageFlags)
Removes the specified flags in-place.
sourcepub fn toggle(&mut self, other: MessageFlags)
pub fn toggle(&mut self, other: MessageFlags)
Toggles the specified flags in-place.
sourcepub fn set(&mut self, other: MessageFlags, value: bool)
pub fn set(&mut self, other: MessageFlags, value: bool)
Inserts or removes the specified flags depending on the passed value.
sourcepub const fn intersection(self, other: MessageFlags) -> MessageFlags
pub const fn intersection(self, other: MessageFlags) -> MessageFlags
Returns the intersection between the flags in self and
other.
Specifically, the returned set contains only the flags which are
present in both self and other.
This is equivalent to using the & operator (e.g.
ops::BitAnd), as in flags & other.
sourcepub const fn union(self, other: MessageFlags) -> MessageFlags
pub const fn union(self, other: MessageFlags) -> MessageFlags
Returns the union of between the flags in self and other.
Specifically, the returned set contains all flags which are
present in either self or other, including any which are
present in both (see Self::symmetric_difference if that
is undesirable).
This is equivalent to using the | operator (e.g.
ops::BitOr), as in flags | other.
sourcepub const fn difference(self, other: MessageFlags) -> MessageFlags
pub const fn difference(self, other: MessageFlags) -> MessageFlags
Returns the difference between the flags in self and other.
Specifically, the returned set contains all flags present in
self, except for the ones present in other.
It is also conceptually equivalent to the “bit-clear” operation:
flags & !other (and this syntax is also supported).
This is equivalent to using the - operator (e.g.
ops::Sub), as in flags - other.
sourcepub const fn symmetric_difference(self, other: MessageFlags) -> MessageFlags
pub const fn symmetric_difference(self, other: MessageFlags) -> MessageFlags
Returns the symmetric difference between the flags
in self and other.
Specifically, the returned set contains the flags present which
are present in self or other, but that are not present in
both. Equivalently, it contains the flags present in exactly
one of the sets self and other.
This is equivalent to using the ^ operator (e.g.
ops::BitXor), as in flags ^ other.
sourcepub const fn complement(self) -> MessageFlags
pub const fn complement(self) -> MessageFlags
Returns the complement of this set of flags.
Specifically, the returned set contains all the flags which are
not set in self, but which are allowed for this type.
Alternatively, it can be thought of as the set difference
between Self::all() and self (e.g. Self::all() - self)
This is equivalent to using the ! operator (e.g.
ops::Not), as in !flags.