Enum discord_flows::http::routing::Route
source · #[non_exhaustive]pub enum Route {
Show 85 variants
ChannelsId(u64),
ChannelsIdInvites(u64),
ChannelsIdMessages(u64),
ChannelsIdMessagesBulkDelete(u64),
ChannelsIdMessagesId(LightMethod, u64),
ChannelsIdMessagesIdAck(u64),
ChannelsIdMessagesIdReactions(u64),
ChannelsIdMessagesIdReactionsUserIdType(u64),
ChannelsIdPermissionsOverwriteId(u64),
ChannelsIdPins(u64),
ChannelsIdPinsMessageId(u64),
ChannelsIdCrosspostsMessageId(u64),
ChannelsIdTyping(u64),
ChannelsIdWebhooks(u64),
ChannelsIdMessagesIdThreads(u64),
ChannelsIdThreads(u64),
ChannelsIdThreadMembersMe(u64),
ChannelsIdThreadMembersUserId(u64),
ChannelsIdThreadMembers(u64),
ChannelsIdArchivedPublicThreads(u64),
ChannelsIdArchivedPrivateThreads(u64),
ChannelsIdMeJoindedArchivedPrivateThreads(u64),
FollowNewsChannel(u64),
Gateway,
GatewayBot,
Guilds,
GuildsId(u64),
GuildsIdAutoModRules(u64),
GuildsIdAutoModRulesId(u64),
GuildsIdBans(u64),
GuildsIdAuditLogs(u64),
GuildsIdBansUserId(u64),
GuildsIdChannels(u64),
GuildsIdWidget(u64),
GuildsIdPreview(u64),
GuildsIdEmojis(u64),
GuildsIdEmojisId(u64),
GuildsIdIntegrations(u64),
GuildsIdIntegrationsId(u64),
GuildsIdIntegrationsIdSync(u64),
GuildsIdInvites(u64),
GuildsIdMembers(u64),
GuildsIdMembersId(u64),
GuildsIdMembersIdRolesId(u64),
GuildsIdMembersMe(u64),
GuildsIdMembersMeNick(u64),
GuildsIdMembersSearch(u64),
GuildsIdPrune(u64),
GuildsIdRegions(u64),
GuildsIdRoles(u64),
GuildsIdRolesId(u64),
GuildsIdScheduledEvents(u64),
GuildsIdScheduledEventsId(u64),
GuildsIdScheduledEventsIdUsers(u64),
GuildsIdStickers(u64),
GuildsIdStickersId(u64),
GuildsIdVanityUrl(u64),
GuildsIdVoiceStates(u64),
GuildsIdVoiceStatesMe(u64),
GuildsIdWebhooks(u64),
GuildsIdWelcomeScreen(u64),
GuildsIdThreadsActive,
InvitesCode,
StickerPacks,
StickersId,
UsersId,
UsersMe,
UsersMeChannels,
UsersMeConnections,
UsersMeGuilds,
UsersMeGuildsId,
VoiceRegions,
WebhooksId(u64),
WebhooksIdMessagesId(u64),
WebhooksApplicationId(u64),
InteractionsId(u64),
ApplicationsIdCommands(u64),
ApplicationsIdCommandsId(u64),
ApplicationsIdGuildsIdCommands(u64),
ApplicationsIdGuildsIdCommandsPermissions(u64),
ApplicationsIdGuildsIdCommandIdPermissions(u64),
ApplicationsIdGuildsIdCommandsId(u64),
StageInstances,
StageInstancesChannelId(u64),
None,
}Expand description
A representation of all routes registered within the library. These are safe
and memory-efficient representations of each path that functions exist for
in the http module.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
ChannelsId(u64)
Route for the /channels/:channel_id path.
The data is the relevant ChannelId.
ChannelsIdInvites(u64)
Route for the /channels/:channel_id/invites path.
The data is the relevant ChannelId.
ChannelsIdMessages(u64)
Route for the /channels/:channel_id/messages path.
The data is the relevant ChannelId.
ChannelsIdMessagesBulkDelete(u64)
Route for the /channels/:channel_id/messages/bulk-delete path.
The data is the relevant ChannelId.
ChannelsIdMessagesId(LightMethod, u64)
Route for the /channels/:channel_id/messages/:message_id path.
The data is the relevant ChannelId.
This route is a unique case. The ratelimit for message deletions is different than the overall route ratelimit.
Refer to the docs on Rate Limits in the yellow warning section.
ChannelsIdMessagesIdAck(u64)
Route for the /channels/:channel_id/messages/:message_id/ack path.
The data is the relevant ChannelId.
ChannelsIdMessagesIdReactions(u64)
Route for the /channels/:channel_id/messages/:message_id/reactions
path.
The data is the relevant ChannelId.
ChannelsIdMessagesIdReactionsUserIdType(u64)
Route for the
/channels/:channel_id/messages/:message_id/reactions/:reaction/@me
path.
The data is the relevant ChannelId.
ChannelsIdPermissionsOverwriteId(u64)
Route for the /channels/:channel_id/permissions/:target_id path.
The data is the relevant ChannelId.
ChannelsIdPins(u64)
Route for the /channels/:channel_id/pins path.
The data is the relevant ChannelId.
ChannelsIdPinsMessageId(u64)
Route for the /channels/:channel_id/pins/:message_id path.
The data is the relevant ChannelId.
ChannelsIdCrosspostsMessageId(u64)
Route for the /channels/:channel_id/message/:message_id/crosspost path.
The data is the relevant ChannelId.
ChannelsIdTyping(u64)
Route for the /channels/:channel_id/typing path.
The data is the relevant ChannelId.
ChannelsIdWebhooks(u64)
Route for the /channels/:channel_id/webhooks path.
The data is the relevant ChannelId.
ChannelsIdMessagesIdThreads(u64)
Route for the /channels/:channel_id/messages/:message_id/threads path.
The data is the relevant ChannelId.
ChannelsIdThreads(u64)
Route for the /channels/:channel_id/threads path.
The data is the relevant ChannelId.
ChannelsIdThreadMembersMe(u64)
Route for the /channels/:channel_id/thread-members/@me path.
The data is the relevant ChannelId.
ChannelsIdThreadMembersUserId(u64)
Route for the /channels/:channel_id/thread-members/:user_id path.
The data is the relevant ChannelId.
ChannelsIdThreadMembers(u64)
Route for the /channels/channel_id/thread-members path.
The data is the relevant ChannelId.
ChannelsIdArchivedPublicThreads(u64)
Route for the /channels/:channel_id/threads/archived/public path.
The data is the relevant ChannelId.
ChannelsIdArchivedPrivateThreads(u64)
Route for the /channels/:channel_id/threads/archived/private path.
The data is the relevant ChannelId.
ChannelsIdMeJoindedArchivedPrivateThreads(u64)
Route for the /channels/:channel_id/users/@me/threads/archived/private path.
The data is the relevant ChannelId.
FollowNewsChannel(u64)
Route for the /channels/{channel.id}/followers path.
The data is the relevant ChannelId.
Gateway
Route for the /gateway path.
GatewayBot
Route for the /gateway/bot path.
Guilds
Route for the /guilds path.
GuildsId(u64)
Route for the /guilds/:guild_id path.
The data is the relevant GuildId.
GuildsIdAutoModRules(u64)
Route for the /guilds/:guild_id/auto-moderation/rules path.
GuildsIdAutoModRulesId(u64)
Route for the /guilds/:guild_id/auto-moderation/rules/:rule_id path.
GuildsIdBans(u64)
Route for the /guilds/:guild_id/bans path.
The data is the relevant GuildId.
GuildsIdAuditLogs(u64)
Route for the /guilds/:guild_id/audit-logs path.
The data is the relevant GuildId.
GuildsIdBansUserId(u64)
Route for the /guilds/:guild_id/bans/:user_id path.
The data is the relevant GuildId.
GuildsIdChannels(u64)
Route for the /guilds/:guild_id/channels/:channel_id path.
The data is the relevant GuildId.
GuildsIdWidget(u64)
Route for the /guilds/:guild_id/widget path.
The data is the relevant GuildId.
GuildsIdPreview(u64)
Route for the /guilds/:guild_id/preview path.
The data is the relevant GuildPreview.
GuildsIdEmojis(u64)
Route for the /guilds/:guild_id/emojis path.
The data is the relevant GuildId.
GuildsIdEmojisId(u64)
Route for the /guilds/:guild_id/emojis/:emoji_id path.
The data is the relevant GuildId.
GuildsIdIntegrations(u64)
Route for the /guilds/:guild_id/integrations path.
The data is the relevant GuildId.
GuildsIdIntegrationsId(u64)
Route for the /guilds/:guild_id/integrations/:integration_id path.
The data is the relevant GuildId.
GuildsIdIntegrationsIdSync(u64)
Route for the /guilds/:guild_id/integrations/:integration_id/sync
path.
The data is the relevant GuildId.
GuildsIdInvites(u64)
Route for the /guilds/:guild_id/invites path.
The data is the relevant GuildId.
GuildsIdMembers(u64)
Route for the /guilds/:guild_id/members path.
The data is the relevant GuildId.
GuildsIdMembersId(u64)
Route for the /guilds/:guild_id/members/:user_id path.
The data is the relevant GuildId.
GuildsIdMembersIdRolesId(u64)
Route for the /guilds/:guild_id/members/:user_id/roles/:role_id path.
The data is the relevant GuildId.
GuildsIdMembersMe(u64)
Route for the /guilds/:guild_id/members/@me path.
The data is the relevant GuildId.
GuildsIdMembersMeNick(u64)
Route for the /guilds/:guild_id/members/@me/nick path.
The data is the relevant GuildId.
GuildsIdMembersSearch(u64)
Route for the /guilds/:guild_id/members/search path.
The data is the relevant GuildId.
GuildsIdPrune(u64)
Route for the /guilds/:guild_id/prune path.
The data is the relevant GuildId.
GuildsIdRegions(u64)
Route for the /guilds/:guild_id/regions path.
The data is the relevant GuildId.
GuildsIdRoles(u64)
Route for the /guilds/:guild_id/roles path.
The data is the relevant GuildId.
GuildsIdRolesId(u64)
Route for the /guilds/:guild_id/roles/:role_id path.
The data is the relevant GuildId.
GuildsIdScheduledEvents(u64)
Route for the /guilds/:guild_id/scheduled-events path.
The data is the relevant GuildId.
GuildsIdScheduledEventsId(u64)
Route for the /guilds/:guild_id/scheduled-events/:event_id path.
The data is the relevant GuildId.
GuildsIdScheduledEventsIdUsers(u64)
Route for the /guilds/:guild_id/scheduled-events/:event_id/users path.
The data is the relevant GuildId.
GuildsIdStickers(u64)
Route for the /guilds/:guild_id/stickers path.
The data is the relevant GuildId.
GuildsIdStickersId(u64)
Route for the /guilds/:guild_id/stickers/:sticker_id path.
The data is the relevant GuildId.
GuildsIdVanityUrl(u64)
Route for the /guilds/:guild_id/vanity-url path.
The data is the relevant GuildId.
GuildsIdVoiceStates(u64)
Route for the /guilds/:guild_id/voice-states/:user_id path.
The data is the relevant GuildId.
GuildsIdVoiceStatesMe(u64)
Route for the /guilds/:guild_id/voice-states/@me path.
The data is the relevant GuildId.
GuildsIdWebhooks(u64)
Route for the /guilds/:guild_id/webhooks path.
The data is the relevant GuildId.
GuildsIdWelcomeScreen(u64)
Route for the /guilds/:guild_id/welcome-screen path.
The data is the relevant GuildId.
GuildsIdThreadsActive
Route for the /guilds/:guild_id/threads/active path.
The data is the relevant GuildId.
InvitesCode
Route for the /invites/:code path.
StickerPacks
Route for the /sticker-packs path.
StickersId
Route for the /stickers/:sticker_id path.
UsersId
Route for the /users/:user_id path.
UsersMe
Route for the /users/@me path.
UsersMeChannels
Route for the /users/@me/channels path.
UsersMeConnections
Route for the /users/@me/connections path.
UsersMeGuilds
Route for the /users/@me/guilds path.
UsersMeGuildsId
Route for the /users/@me/guilds/:guild_id path.
VoiceRegions
Route for the /voice/regions path.
WebhooksId(u64)
Route for the /webhooks/:webhook_id path.
WebhooksIdMessagesId(u64)
Route for the /webhooks/:webhook_id/:token/messages/:message_id path.
The data is the relevant WebhookId.
WebhooksApplicationId(u64)
Route for the /webhooks/:application_id path.
The data is the relevant ApplicationId.
InteractionsId(u64)
Route for the /interactions/:interaction_id path.
The data is the relevant InteractionId.
ApplicationsIdCommands(u64)
Route for the /applications/:application_id path.
The data is the relevant ApplicationId.
ApplicationsIdCommandsId(u64)
Route for the /applications/:application_id/commands/:command_id path.
The data is the relevant ApplicationId.
ApplicationsIdGuildsIdCommands(u64)
Route for the /applications/:application_id/guilds/:guild_id path.
The data is the relevant ApplicationId.
ApplicationsIdGuildsIdCommandsPermissions(u64)
Route for the /applications/:application_id/guilds/:guild_id/commands/permissions path.
The data is the relevant ApplicationId.
ApplicationsIdGuildsIdCommandIdPermissions(u64)
Route for the /applications/:application_id/guilds/:guild_id/commands/:command_id/permissions path.
The data is the relevant ApplicationId.
ApplicationsIdGuildsIdCommandsId(u64)
Route for the /applications/:application_id/guilds/:guild_id path.
The data is the relevant ApplicationId.
StageInstances
Route for the /stage-instances path.
The data is the relevant ChannelId.
StageInstancesChannelId(u64)
Route for the /stage-instances/:channel_id path.
The data is the relevant ChannelId.
None
Route where no ratelimit headers are in place (i.e. user account-only routes).
This is a special case, in that if the route is None then pre- and
post-hooks are not executed.